@@ -2,19 +2,9 @@
 function(lib, pkg)
 {
     library.dynam("tseries", pkg, lib)
-    RisLT19 <- ((R.version$major == 1)
-                && (as.numeric(R.version$minor) < 9))
-    if(RisLT19) {
-        if(!require("ts", quietly = TRUE))
-            stop("Package", sQuote("ts"), "is needed.  Stopping")
-    } else {
-        require("stats", quietly = TRUE)
-    }
+    require("stats", quietly = TRUE)
     mylib <- dirname(system.file(package = "tseries"))
-    ver <- if(RisLT19)
-        package.description("tseries", lib = mylib)["Version"]
-    else
-        packageDescription("tseries", lib = mylib)["Version"]
+    ver <- packageDescription("tseries", lib = mylib)["Version"]
     txt <- c("\n",
              paste(sQuote("tseries"), "version:", ver),
              "\n",
